==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/et-EE/admin/hardware/general.php <==
<?php

return [
    'about_assets_title'           => 'Vahenditest',
    'about_assets_text'            => 'Varad on üksused, mida jälgitakse seerianumbri või vara tag. Need kipuvad olema kõrgema väärtusega esemed, kus konkreetse üksuse kindlakstegemine on oluline.',
    'archived'  				=> 'Arhiveeritud',
    'asset'  					=> 'Vahend',
    'bulk_checkout'             => 'Vara kasutusele võtt',
    'bulk_checkin'              => 'Vahendite tagastus',
    'checkin'  					=> 'Checkin Asset',
    'checkout'  				=> 'Checkout Asset',
    'clone'  					=> 'Klooni vahend',
    'deployable'  				=> 'Käivitatav',
    'deleted'  					=> 'See vara on kustutatud.',
    'delete_confirm'            => 'Are you sure you want to delete this asset?',
    'edit'  					=> 'Muuda vahendit',
    'model_deleted'  			=> 'See vara mudel on kustutatud. Enne vara taastamist peab taastama mudeli.',
    'model_invalid'             => 'This model for this asset is invalid.',
    'model_invalid_fix'         => 'The asset must be updated use a valid asset model before attempting to check it in or out, or to audit it.',
    'requestable'               => 'Taotletav',
    'requested'				    => 'Taotletud',
    'not_requestable'           => 'Mittetaotletav',
    'requestable_status_warning' => 'Do not change requestable status',
    'restore'  					=> 'Taasta vara',
    'pending'  					=> 'Ootel',
    'undeployable'  			=> 'Kasutuselevõtmatu',
    'undeployable_tooltip'  	=> 'This asset has a status label that is undeployable and cannot be checked out at this time.',
    'view'  					=> 'Vaata vahendit',
    'csv_error' => 'Sul on viga CSV failis:',
    'import_text' => '<p>Upload a CSV that contains asset history. The assets and users MUST already exist in the system, or they will be skipped. Matching assets for history import happens against the asset tag. We will try to find a matching user based on the user\'s name you provide, and the criteria you select below. If you do not select any criteria below, it will simply try to match on the username format you configured in the <code>Admin &gt; General Settings</code>.</p><p>Fields included in the CSV must match the headers: <strong>Asset Tag, Name, Checkout Date, Checkin Date</strong>. Any additional fields will be ignored. </p><p>Checkin Date: blank or future checkin dates will checkout items to associated user.  Excluding the Checkin Date column will create a checkin date with todays date.</p>
    ',
    'csv_import_match_f-l' => 'Try to match users by <strong>firstname.lastname</strong> (<code>jane.smith</code>) format',
    'csv_import_match_initial_last' => 'Try to match users by <strong>first initial last name</strong> (<code>jsmith</code>) format',
    'csv_import_match_first' => 'Try to match users by <strong>first name</strong> (<code>jane</code>) format',
    'csv_import_match_email' => 'Try to match users by <strong>email</strong> as username',
    'csv_import_match_username' => 'Try to match users by <strong>username</strong>',
    'error_messages' => 'Tõrked:',
    'success_messages' => 'Õnnestumised:',
    'alert_details' => 'Palun vaata allolevaid üksikasju.',
    'custom_export' => 'Custom Export',
    'mfg_warranty_lookup' => ':manufacturer Warranty Status Lookup',
    'user_department' => 'User Department',
];

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/et-EE/admin/hardware/general.php <==
<?php

return [
    'about_assets_title'           => 'Vahenditest',
    'about_assets_text'            => 'Varad on üksused, mida jälgitakse seerianumbri või vara tag. Need kipuvad olema kõrgema väärtusega esemed, kus konkreetse üksuse kindlakstegemine on oluline.',
    'archived'  				=> 'Arhiveeritud',
    'asset'  					=> 'Vahend',
    'bulk_checkout'             => 'Bulk Checkout',
    'bulk_checkin'              => 'Bulk Checkin',
    'checkin'  					=> 'Checkin Asset',
    'checkout'  				=> 'Checkout Asset',
    'clone'  					=> 'Klooni vahend',
    'deployable'  				=> 'Käivitatav',
    'deleted'  					=> 'See vara on kustutatud.',
    'delete_confirm'            => 'Are you sure you want to delete this asset?',
    'edit'  					=> 'Muuda vahendit',
    'model_deleted'  			=> 'See vara mudel on kustutatud. Enne vara taastamist peab taastama mudeli.',
    'model_invalid'             => 'This model for this asset is invalid.',
    'model_invalid_fix'         => 'The asset must be updated use a valid asset model before attempting to check it in or out, or to audit it.',
    'requestable'               => 'Taotletav',
    'requested'				    => 'Taotletud',
    'not_requestable'           => 'Mittetaotletav',
    'requestable_status_warning' => 'Do not change requestable status',
    'restore'  					=> 'Taasta vara',
    'pending'  					=> 'Ootel',
    'undeployable'  			=> 'Kasutuselevõtmatu',
    'undeployable_tooltip'  	=> 'This asset has a status label that is undeployable and cannot be checked out at this time.',
    'view'  					=> 'Vaata vahendit',
    'csv_error' => 'Sul on viga CSV failis:',
    'import_text' => '<p>Upload a CSV that contains asset history. The assets and users MUST already exist in the system, or they will be skipped. Matching assets for history import happens against the asset tag. We will try to find a matching user based on the user\'s name you provide, and the criteria you select below. If you do not select any criteria below, it will simply try to match on the username format you configured in the <code>Admin &gt; General Settings</code>.</p><p>Fields included in the CSV must match the headers: <strong>Asset Tag, Name, Checkout Date, Checkin Date</strong>. Any additional fields will be ignored. </p><p>Checkin Date: blank or future checkin dates will checkout items to associated user.  Excluding the Checkin Date column will create a checkin date with todays date.</p>
    ',
    'csv_import_match_f-l' => 'Try to match users by <strong>firstname.lastname</strong> (<code>jane.smith</code>) format',
    'csv_import_match_initial_last' => 'Try to match users by <strong>first initial last name</strong> (<code>jsmith</code>) format',
    'csv_import_match_first' => 'Try to match users by <strong>first name</strong> (<code>jane</code>) format',
    'csv_import_match_email' => 'Try to match users by <strong>email</strong> as username',
    'csv_import_match_username' => 'Try to match users by <strong>username</strong>',
    'error_messages' => 'Tõrked:',
    'success_messages' => 'Õnnestumised:',
    'alert_details' => 'Palun vaata allolevaid üksikasju.',
    'custom_export' => 'Custom Export',
    'mfg_warranty_lookup' => ':manufacturer Warranty Status Lookup',
    'user_department' => 'User Department',
];
